@@ -7,6 +7,7 @@ from typing import TYPE_CHECKING
 from typing import cast
 
 import pytest
+import tomlkit
 
 from packaging.utils import canonicalize_name
 from poetry.core.constraints.version import Version
@@ -595,6 +596,230 @@ Writing lock file
     assert content["dependencies"]["demo"] == expected_content
 
 
+def test_add_to_new_group_keeps_existing_group(
+    app: PoetryTestApplication, tester: CommandTester
+) -> None:
+    pyproject: dict[str, Any] = app.poetry.file.read()
+    groups_content: dict[str, Any] = tomlkit.parse(
+        """\
+[dependency-groups]
+example = [
+    "cachy (>=0.2.0,<0.3.0)",
+]
+"""
+    )
+    pyproject["dependency-groups"] = groups_content["dependency-groups"]
+    pyproject = cast("TOMLDocument", pyproject)
+    app.poetry.file.write(pyproject)
+
+    tester.execute("-G foo pendulum")
+
+    expected = """\
+Using version ^1.4.4 for pendulum
+"""
+
+    assert tester.io.fetch_output().startswith(expected)
+    assert isinstance(tester.command, InstallerCommand)
+    assert tester.command.installer.executor.installations_count == 1
+
+    pyproject = app.poetry.file.read()
+    pyproject = cast("dict[str, Any]", pyproject)
+    assert "example" in pyproject["dependency-groups"]
+    assert pyproject["dependency-groups"]["example"] == [
+        "cachy (>=0.2.0,<0.3.0)",
+    ]
+    assert pyproject["dependency-groups"]["foo"] == [
+        "pendulum (>=1.4.4,<2.0.0)",
+    ]
+
+
+@pytest.mark.parametrize("additional_poetry_group", [False, True])
+def test_add_to_existing_group(
+    app: PoetryTestApplication, tester: CommandTester, additional_poetry_group: bool
+) -> None:
+    pyproject: dict[str, Any] = app.poetry.file.read()
+    groups_content: dict[str, Any] = tomlkit.parse(
+        """\
+[dependency-groups]
+example = [
+    "cachy (>=0.2.0,<0.3.0)",
+]
+"""
+    )
+    pyproject["dependency-groups"] = groups_content["dependency-groups"]
+    if additional_poetry_group:
+        poetry_groups_content: dict[str, Any] = tomlkit.parse(
+            """\
+[tool.poetry.group.example.dependencies]
+cachy = { allow-prereleases = true }
+"""
+        )
+        pyproject["tool"]["poetry"]["group"] = poetry_groups_content["tool"]["poetry"][
+            "group"
+        ]
+    pyproject = cast("TOMLDocument", pyproject)
+    app.poetry.file.write(pyproject)
+
+    tester.execute("-G example pendulum")
+
+    expected = """\
+Using version ^1.4.4 for pendulum
+"""
+
+    assert tester.io.fetch_output().startswith(expected)
+    assert isinstance(tester.command, InstallerCommand)
+    assert tester.command.installer.executor.installations_count == 1
+
+    pyproject = app.poetry.file.read()
+    pyproject = cast("dict[str, Any]", pyproject)
+    assert "example" in pyproject["dependency-groups"]
+    assert pyproject["dependency-groups"]["example"] == [
+        "cachy (>=0.2.0,<0.3.0)",
+        "pendulum (>=1.4.4,<2.0.0)",
+    ]
+    if additional_poetry_group:
+        assert "example" in pyproject["tool"]["poetry"]["group"]
+        assert pyproject["tool"]["poetry"]["group"]["example"]["dependencies"] == {
+            "cachy": {"allow-prereleases": True},
+        }
+    else:
+        assert "group" not in pyproject["tool"]["poetry"]
+
+
+def test_add_to_group_with_latest_overwrite_existing(
+    app: PoetryTestApplication, tester: CommandTester
+) -> None:
+    pyproject: dict[str, Any] = app.poetry.file.read()
+    groups_content: dict[str, Any] = tomlkit.parse(
+        """\
+[dependency-groups]
+example = [
+    "cachy (>=0.1.0,<0.2.0)",
+    "pendulum (>=1.4.4,<2.0.0)",
+]
+"""
+    )
+    pyproject["dependency-groups"] = groups_content["dependency-groups"]
+    pyproject = cast("TOMLDocument", pyproject)
+    app.poetry.file.write(pyproject)
+
+    tester.execute("-G example cachy@latest")
+
+    expected = """\
+Using version ^0.2.0 for cachy
+"""
+
+    assert tester.io.fetch_output().startswith(expected)
+    assert isinstance(tester.command, InstallerCommand)
+    # `cachy` has `msgpack-python` as dependency. So installation count increases by 1.
+    assert tester.command.installer.executor.installations_count == 2
+
+    pyproject = app.poetry.file.read()
+    pyproject = cast("dict[str, Any]", pyproject)
+    assert "example" in pyproject["dependency-groups"]
+    assert pyproject["dependency-groups"]["example"] == [
+        "cachy (>=0.2.0,<0.3.0)",
+        "pendulum (>=1.4.4,<2.0.0)",
+    ]
+
+
+def test_add_multiple_dependencies_to_dependency_group(
+    app: PoetryTestApplication, tester: CommandTester
+) -> None:
+    tester.execute("-G example cachy pendulum")
+
+    expected = """\
+Using version ^0.2.0 for cachy
+Using version ^1.4.4 for pendulum
+"""
+
+    assert tester.io.fetch_output().startswith(expected)
+
+    pyproject: dict[str, Any] = app.poetry.file.read()
+    assert isinstance(tester.command, InstallerCommand)
+    # `cachy` has `msgpack-python` as dependency. So installation count increases by 1.
+    assert tester.command.installer.executor.installations_count == 3
+
+    assert "example" in pyproject["dependency-groups"]
+    assert pyproject["dependency-groups"]["example"] == [
+        "cachy (>=0.2.0,<0.3.0)",
+        "pendulum (>=1.4.4,<2.0.0)",
+    ]
+
+
+def test_add_to_group_uses_existing_legacy_group(
+    app: PoetryTestApplication, tester: CommandTester
+) -> None:
+    pyproject: dict[str, Any] = app.poetry.file.read()
+    groups_content: dict[str, Any] = tomlkit.parse(
+        """\
+[tool.poetry.group.example.dependencies]
+pendulum = "^1.4.4"
+"""
+    )
+    pyproject["tool"]["poetry"]["group"] = groups_content["tool"]["poetry"]["group"]
+
+    pyproject = cast("TOMLDocument", pyproject)
+    app.poetry.file.write(pyproject)
+
+    tester.execute("-G example cachy")
+
+    expected = """\
+Using version ^0.2.0 for cachy
+"""
+
+    assert tester.io.fetch_output().startswith(expected)
+    assert isinstance(tester.command, InstallerCommand)
+    # `cachy` has `msgpack-python` as dependency. So installation count increases by 1.
+    assert tester.command.installer.executor.installations_count == 2
+
+    pyproject = app.poetry.file.read()
+    pyproject = cast("dict[str, Any]", pyproject)
+    assert "dependency-groups" not in pyproject
+    assert "example" in pyproject["tool"]["poetry"]["group"]
+    assert "pendulum" in pyproject["tool"]["poetry"]["group"]["example"]["dependencies"]
+    assert "cachy" in pyproject["tool"]["poetry"]["group"]["example"]["dependencies"]
+
+
+@pytest.mark.parametrize(
+    "required_fixtures",
+    [["git/github.com/demo/demo"]],
+)
+def test_add_group_directory_constraint_mix_pep735(
+    app: PoetryTestApplication,
+    tester: CommandTester,
+) -> None:
+    path = "../git/github.com/demo/demo"
+    tester.execute(f"-G example -e {path}")
+
+    demo_path = app.poetry.file.path.parent.joinpath(path).resolve().as_posix()
+    expected = f"""\
+
+Updating dependencies
+Resolving dependencies...
+
+Package operations: 2 installs, 0 updates, 0 removals
+
+  - Installing pendulum (1.4.4)
+  - Installing demo (0.1.2 {demo_path})
+
+Writing lock file
+"""
+
+    assert tester.io.fetch_output() == expected
+    assert isinstance(tester.command, InstallerCommand)
+    assert tester.command.installer.executor.installations_count == 2
+
+    pyproject: dict[str, Any] = app.poetry.file.read()
+
+    assert "demo @ file://" in pyproject["dependency-groups"]["example"][0]
+    assert demo_path in pyproject["dependency-groups"]["example"][0]
+    assert "demo" in pyproject["tool"]["poetry"]["group"]["example"]["dependencies"]
+    assert pyproject["tool"]["poetry"]["group"]["example"]["dependencies"]["demo"] == {
+        "develop": True
+    }
+
+
 @pytest.mark.parametrize(
     "required_fixtures",
     [["git/github.com/demo/pyproject-demo"]],
@@ -1078,17 +1303,15 @@ Writing lock file
     assert tester.command.installer.executor.installations_count == 2
 
     pyproject: dict[str, Any] = app.poetry.file.read()
-    content = pyproject["tool"]["poetry"]
+    content = pyproject["dependency-groups"]
 
-    assert "cachy" in content["group"][group_name]["dependencies"]
-    assert content["group"][group_name]["dependencies"]["cachy"] == "^0.2.0"
+    assert content[group_name][0] == "cachy (>=0.2.0,<0.3.0)"
 
     escaped_group_name = f'"{group_name}"' if "." in group_name else group_name
     expected = f"""\
-
-[tool.poetry.group.{escaped_group_name}.dependencies]
-cachy = "^0.2.0"
-
+{escaped_group_name} = [
+    "cachy (>=0.2.0,<0.3.0)"
+]
 """
     string_content = content.as_string()
     if "\r\n" in string_content:
@@ -1118,15 +1341,14 @@ def test_add_creating_poetry_section_does_not_remove_existing_tools(
     assert tester.command.installer.executor.installations_count == 2
 
     pyproject: dict[str, Any] = poetry.file.read()
-    content = pyproject["tool"]["poetry"]
+    content = pyproject["dependency-groups"]
 
-    assert "cachy" in content["group"]["dev"]["dependencies"]
-    assert content["group"]["dev"]["dependencies"]["cachy"] == "^0.2.0"
+    assert content["dev"][0] == "cachy (>=0.2.0,<0.3.0)"
     assert "foo" in pyproject["tool"]
     assert pyproject["tool"]["foo"]["key"] == "value"
 
 
-def test_add_to_dev_section(app: PoetryTestApplication, tester: CommandTester) -> None:
+def test_add_to_dev_group(app: PoetryTestApplication, tester: CommandTester) -> None:
     tester.execute("cachy --dev")
 
     expected = """\
@@ -1149,10 +1371,9 @@ Writing lock file
     assert tester.command.installer.executor.installations_count == 2
 
     pyproject: dict[str, Any] = app.poetry.file.read()
-    content = pyproject["tool"]["poetry"]
+    content = pyproject["dependency-groups"]
 
-    assert "cachy" in content["group"]["dev"]["dependencies"]
-    assert content["group"]["dev"]["dependencies"]["cachy"] == "^0.2.0"
+    assert content["dev"][0] == "cachy (>=0.2.0,<0.3.0)"
 
 
 def test_add_should_not_select_prereleases(
