@@ -5,15 +5,18 @@ from typing import TYPE_CHECKING
 from poetry.core.packages.package import Package
 
 from poetry.factory import Factory
-from poetry.mixology.failure import SolveFailure
+from poetry.mixology.failure import SolveFailureError
 from poetry.mixology.version_solver import VersionSolver
-from poetry.packages import DependencyPackage
 
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from packaging.utils import NormalizedName
+    from poetry.core.factory import DependencyConstraint
     from poetry.core.packages.project_package import ProjectPackage
 
-    from poetry.mixology import SolverResult
+    from poetry.mixology.result import SolverResult
     from poetry.repositories import Repository
     from tests.mixology.version_solver.conftest import Provider
 
@@ -22,7 +25,7 @@ def add_to_repo(
     repository: Repository,
     name: str,
     version: str,
-    deps: dict[str, str] | None = None,
+    deps: Mapping[str, DependencyConstraint] | None = None,
     python: str | None = None,
     yanked: bool = False,
 ) -> None:
@@ -43,32 +46,26 @@ def check_solver_result(
     result: dict[str, str] | None = None,
     error: str | None = None,
     tries: int | None = None,
-    locked: dict[str, Package] | None = None,
-    use_latest: list[str] | None = None,
+    use_latest: list[NormalizedName] | None = None,
 ) -> SolverResult | None:
-    if locked is not None:
-        locked = {
-            k: [DependencyPackage(l.to_dependency(), l)] for k, l in locked.items()
-        }
+    solver = VersionSolver(root, provider)
+    with provider.use_latest_for(use_latest or []):
+        try:
+            solution = solver.solve()
+        except SolveFailureError as e:
+            if error:
+                assert str(e) == error
 
-    solver = VersionSolver(root, provider, locked=locked, use_latest=use_latest)
-    try:
-        solution = solver.solve()
-    except SolveFailure as e:
-        if error:
-            assert str(e) == error
-
-            if tries is not None:
-                assert solver.solution.attempted_solutions == tries
+                if tries is not None:
+                    assert solver.solution.attempted_solutions == tries
 
             return None
 
-        raise
-    except AssertionError as e:
-        if error:
-            assert str(e) == error
-            return None
-        raise
+        except AssertionError as e:
+            if error:
+                assert str(e) == error
+                return None
+            raise
 
     packages = {}
     for package in solution.packages:
